summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:10:39 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:10:39 -0600
commit28723595822268551d3e050c3a83bf6ca5e17dd5 (patch)
treec84224b55e09375ad246f24649df1ffc89c04d1d /kmymoney2/widgets
parent1f9d00360b9018301630ce062d7dda0c6583edfb (diff)
downloadkmymoney-28723595822268551d3e050c3a83bf6ca5e17dd5.tar.gz
kmymoney-28723595822268551d3e050c3a83bf6ca5e17dd5.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kmymoney2/widgets')
-rw-r--r--kmymoney2/widgets/kaccounttemplateselectordecl.cpp16
-rw-r--r--kmymoney2/widgets/kaccounttemplateselectordecl.ui4
-rw-r--r--kmymoney2/widgets/kbudgetvaluesdecl.cpp4
-rw-r--r--kmymoney2/widgets/kbudgetvaluesdecl.ui4
-rw-r--r--kmymoney2/widgets/kguiutils.cpp4
-rw-r--r--kmymoney2/widgets/klistviewsearchline.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreebase.cpp6
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp20
-rw-r--r--kmymoney2/widgets/kmymoneybriefschedule.cpp10
-rw-r--r--kmymoney2/widgets/kmymoneycalculator.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneycalendar.cpp34
-rw-r--r--kmymoney2/widgets/kmymoneycalendar.h4
-rw-r--r--kmymoney2/widgets/kmymoneycombo.cpp14
-rw-r--r--kmymoney2/widgets/kmymoneycombo.h2
-rw-r--r--kmymoney2/widgets/kmymoneycompletion.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneydateinput.cpp18
-rw-r--r--kmymoney2/widgets/kmymoneydateinput.h4
-rw-r--r--kmymoney2/widgets/kmymoneydatetbl.cpp10
-rw-r--r--kmymoney2/widgets/kmymoneydatetbl.h6
-rw-r--r--kmymoney2/widgets/kmymoneyedit.cpp12
-rw-r--r--kmymoney2/widgets/kmymoneyedit.h2
-rw-r--r--kmymoney2/widgets/kmymoneygpgconfigdecl.ui4
-rw-r--r--kmymoney2/widgets/kmymoneylineedit.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui4
-rw-r--r--kmymoney2/widgets/kmymoneyreportconfigtab1decl.ui2
-rw-r--r--kmymoney2/widgets/kmymoneyreportconfigtab2decl.ui4
-rw-r--r--kmymoney2/widgets/kmymoneyreportconfigtab3decl.ui14
-rw-r--r--kmymoney2/widgets/kmymoneyreportconfigtabchartdecl.ui6
-rw-r--r--kmymoney2/widgets/kmymoneyreportcontroldecl.ui14
-rw-r--r--kmymoney2/widgets/kmymoneyscheduledcalendar.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneyscheduleddatetbl.cpp8
-rw-r--r--kmymoney2/widgets/kmymoneyscheduleddatetbl.h2
-rw-r--r--kmymoney2/widgets/kmymoneyselector.cpp4
-rw-r--r--kmymoney2/widgets/kmymoneytitlelabel.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneywizard.cpp6
-rw-r--r--kmymoney2/widgets/kschedulebriefwidget.ui18
-rw-r--r--kmymoney2/widgets/register.cpp10
-rw-r--r--kmymoney2/widgets/transaction.cpp88
-rw-r--r--kmymoney2/widgets/transaction.h2
-rw-r--r--kmymoney2/widgets/transactionform.cpp14
-rw-r--r--kmymoney2/widgets/transactionform.h2
-rw-r--r--kmymoney2/widgets/transactionsortoption.ui8
42 files changed, 198 insertions, 198 deletions
diff --git a/kmymoney2/widgets/kaccounttemplateselectordecl.cpp b/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
index 75f3d16..14170c7 100644
--- a/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
+++ b/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
@@ -39,7 +39,7 @@ KAccountTemplateSelectorDecl::KAccountTemplateSelectorDecl( TQWidget* parent, co
m_groupList = new KListView( this, "m_groupList" );
m_groupList->addColumn( kmm_i18n( "Account Types" ) );
m_groupList->addColumn( kmm_i18n( "Description" ) );
- m_groupList->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 0, m_groupList->sizePolicy().hasHeightForWidth() ) );
+ m_groupList->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 0, m_groupList->sizePolicy().hasHeightForWidth() ) );
m_groupList->setMinimumSize( TQSize( 0, 150 ) );
m_groupList->setProperty( "selectionMode", "Extended" );
m_groupList->setAllColumnsShowFocus( TRUE );
@@ -50,30 +50,30 @@ KAccountTemplateSelectorDecl::KAccountTemplateSelectorDecl( TQWidget* parent, co
tqlayout3 = new TQHBoxLayout( 0, 0, 6, "tqlayout3");
groupBox1 = new TQGroupBox( this, "groupBox1" );
- groupBox1->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 2, groupBox1->sizePolicy().hasHeightForWidth() ) );
+ groupBox1->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 2, groupBox1->sizePolicy().hasHeightForWidth() ) );
groupBox1->setColumnLayout(0, Qt::Vertical );
groupBox1->tqlayout()->setSpacing( 6 );
groupBox1->tqlayout()->setMargin( 11 );
groupBox1Layout = new TQVBoxLayout( groupBox1->tqlayout() );
- groupBox1Layout->tqsetAlignment( TQt::AlignTop );
+ groupBox1Layout->setAlignment( TQt::AlignTop );
m_description = new KTextEdit( groupBox1, "m_description" );
- m_description->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 3, m_description->sizePolicy().hasHeightForWidth() ) );
+ m_description->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 3, m_description->sizePolicy().hasHeightForWidth() ) );
m_description->setReadOnly( TRUE );
groupBox1Layout->addWidget( m_description );
tqlayout3->addWidget( groupBox1 );
groupBox2 = new TQGroupBox( this, "groupBox2" );
- groupBox2->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 1, 2, groupBox2->sizePolicy().hasHeightForWidth() ) );
+ groupBox2->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 1, 2, groupBox2->sizePolicy().hasHeightForWidth() ) );
groupBox2->setColumnLayout(0, Qt::Vertical );
groupBox2->tqlayout()->setSpacing( 6 );
groupBox2->tqlayout()->setMargin( 11 );
groupBox2Layout = new TQVBoxLayout( groupBox2->tqlayout() );
- groupBox2Layout->tqsetAlignment( TQt::AlignTop );
+ groupBox2Layout->setAlignment( TQt::AlignTop );
m_accountList = new KListView( groupBox2, "m_accountList" );
m_accountList->addColumn( kmm_i18n( "Name" ) );
- m_accountList->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 3, m_accountList->sizePolicy().hasHeightForWidth() ) );
+ m_accountList->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 3, m_accountList->sizePolicy().hasHeightForWidth() ) );
m_accountList->setMinimumSize( TQSize( 0, 150 ) );
m_accountList->setProperty( "selectionMode", "NoSelection" );
m_accountList->setAllColumnsShowFocus( TRUE );
@@ -83,7 +83,7 @@ KAccountTemplateSelectorDecl::KAccountTemplateSelectorDecl( TQWidget* parent, co
tqlayout3->addWidget( groupBox2 );
KAccountTemplateSelectorDeclLayout->addLayout( tqlayout3 );
languageChange();
- resize( TQSize(546, 346).expandedTo(tqminimumSizeHint()) );
+ resize( TQSize(546, 346).expandedTo(minimumSizeHint()) );
clearWState( WState_Polished );
}
diff --git a/kmymoney2/widgets/kaccounttemplateselectordecl.ui b/kmymoney2/widgets/kaccounttemplateselectordecl.ui
index deb37ab..a028765 100644
--- a/kmymoney2/widgets/kaccounttemplateselectordecl.ui
+++ b/kmymoney2/widgets/kaccounttemplateselectordecl.ui
@@ -53,7 +53,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>150</height>
@@ -159,7 +159,7 @@
<verstretch>3</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>150</height>
diff --git a/kmymoney2/widgets/kbudgetvaluesdecl.cpp b/kmymoney2/widgets/kbudgetvaluesdecl.cpp
index 385cbfa..d5d3382 100644
--- a/kmymoney2/widgets/kbudgetvaluesdecl.cpp
+++ b/kmymoney2/widgets/kbudgetvaluesdecl.cpp
@@ -183,7 +183,7 @@ KBudgetValuesDecl::KBudgetValuesDecl( TQWidget* parent, const char* name, WFlags
m_periodGroup->tqlayout()->setSpacing( 6 );
m_periodGroup->tqlayout()->setMargin( 11 );
m_periodGroupLayout = new TQVBoxLayout( m_periodGroup->tqlayout() );
- m_periodGroupLayout->tqsetAlignment( TQt::AlignTop );
+ m_periodGroupLayout->setAlignment( TQt::AlignTop );
m_monthlyButton = new TQRadioButton( m_periodGroup, "m_monthlyButton" );
m_periodGroupLayout->addWidget( m_monthlyButton );
@@ -198,7 +198,7 @@ KBudgetValuesDecl::KBudgetValuesDecl( TQWidget* parent, const char* name, WFlags
KBudgetValuesDeclLayout->addMultiCellWidget( m_periodGroup, 0, 5, 0, 0 );
languageChange();
- resize( TQSize(553, 188).expandedTo(tqminimumSizeHint()) );
+ resize( TQSize(553, 188).expandedTo(minimumSizeHint()) );
clearWState( WState_Polished );
// tab order
diff --git a/kmymoney2/widgets/kbudgetvaluesdecl.ui b/kmymoney2/widgets/kbudgetvaluesdecl.ui
index 0eb9cb7..fb767ea 100644
--- a/kmymoney2/widgets/kbudgetvaluesdecl.ui
+++ b/kmymoney2/widgets/kbudgetvaluesdecl.ui
@@ -306,7 +306,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>21</height>
@@ -360,7 +360,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>21</height>
diff --git a/kmymoney2/widgets/kguiutils.cpp b/kmymoney2/widgets/kguiutils.cpp
index 1b17ac6..e8e8d3f 100644
--- a/kmymoney2/widgets/kguiutils.cpp
+++ b/kmymoney2/widgets/kguiutils.cpp
@@ -96,7 +96,7 @@ void kMandatoryFieldGroup::add(TQWidget *widget)
void kMandatoryFieldGroup::remove(TQWidget *widget)
{
- widget->setPaletteBackgroundColor(widget->tqcolorGroup().background());
+ widget->setPaletteBackgroundColor(widget->colorGroup().background());
widgets.remove(widget);
changed();
}
@@ -164,7 +164,7 @@ void kMandatoryFieldGroup::clear(void)
{
TQValueList<TQWidget *>::Iterator i;
for (i = widgets.begin(); i != widgets.end(); ++i)
- (*i)->setPaletteBackgroundColor((*i)->tqcolorGroup().background());
+ (*i)->setPaletteBackgroundColor((*i)->colorGroup().background());
widgets.clear();
if (okButton) {
okButton->setEnabled(true);
diff --git a/kmymoney2/widgets/klistviewsearchline.cpp b/kmymoney2/widgets/klistviewsearchline.cpp
index 8c01629..97431b1 100644
--- a/kmymoney2/widgets/klistviewsearchline.cpp
+++ b/kmymoney2/widgets/klistviewsearchline.cpp
@@ -147,7 +147,7 @@ void KListViewSearchLine::updateSearch(const TQString &s)
it.current() && !currentItem;
++it)
{
- if(d->listView->tqitemRect(it.current()).isValid())
+ if(d->listView->itemRect(it.current()).isValid())
currentItem = it.current();
}
}
diff --git a/kmymoney2/widgets/kmymoneyaccounttreebase.cpp b/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
index 48ecd28..c6c5d6d 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
+++ b/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
@@ -238,7 +238,7 @@ bool KMyMoneyAccountTreeBase::acceptDrag(TQDropEvent* event) const
if((rc = (acceptDrops()) && (event->source() == viewport()))) {
rc = false;
KMyMoneyAccountTreeBaseItem* to = dynamic_cast<KMyMoneyAccountTreeBaseItem*>(itemAt( contentsToViewport(event->pos()) ));
- TQString fromId(event->tqencodedData("text/plain"));
+ TQString fromId(event->encodedData("text/plain"));
const KMyMoneyAccountTreeBaseItem* from = findItem(fromId);
// we can only move accounts around
@@ -296,7 +296,7 @@ void KMyMoneyAccountTreeBase::slotObjectDropped(TQDropEvent* event, TQListViewIt
KMyMoneyAccountTreeBaseItem* newParent = dynamic_cast<KMyMoneyAccountTreeBaseItem*>(m_dropItem);
if(newParent) {
- TQString fromId(event->tqencodedData("text/plain"));
+ TQString fromId(event->encodedData("text/plain"));
const KMyMoneyAccountTreeBaseItem* from = findItem(fromId);
// we can only move accounts around
@@ -514,7 +514,7 @@ void KMyMoneyAccountTreeBase::viewportPaintEvent(TQPaintEvent* e)
TQPainter painter(viewport());
// This is where we actually draw the drop-highlighter
- tqstyle().tqdrawPrimitive(TQStyle::PE_FocusRect, &painter, m_lastDropHighlighter, tqcolorGroup(),
+ tqstyle().tqdrawPrimitive(TQStyle::PE_FocusRect, &painter, m_lastDropHighlighter, colorGroup(),
TQStyle::Style_FocusAtBorder);
}
}
diff --git a/kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp b/kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp
index 950200e..1d1717c 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp
+++ b/kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp
@@ -57,8 +57,8 @@ void KMyMoneyAccountTreeForecast::showSummary(MyMoneyForecast& forecast)
addColumn(i18n("Current"), -1);
//if beginning of forecast is today, set the begin day to next cycle to avoid repeating the first cycle
- if(TQDate::tqcurrentDate() < forecast.beginForecastDate()) {
- daysToBeginDay = TQDate::tqcurrentDate().daysTo(forecast.beginForecastDate());
+ if(TQDate::currentDate() < forecast.beginForecastDate()) {
+ daysToBeginDay = TQDate::currentDate().daysTo(forecast.beginForecastDate());
} else {
daysToBeginDay = forecast.accountsCycle();
}
@@ -84,7 +84,7 @@ void KMyMoneyAccountTreeForecast::showDetailed(MyMoneyForecast& forecast)
addColumn(i18n("Current"), -1);
for(int i = 1; i <= forecast.forecastDays(); ++i) {
- TQDate forecastDate = TQDate::tqcurrentDate().addDays(i);
+ TQDate forecastDate = TQDate::currentDate().addDays(i);
TQString columnName = KGlobal::locale()->formatDate(forecastDate, true);
addColumn(columnName, -1);
}
@@ -103,8 +103,8 @@ void KMyMoneyAccountTreeForecast::showAdvanced(MyMoneyForecast& forecast)
int daysToBeginDay;
//if beginning of forecast is today, set the begin day to next cycle to avoid repeating the first cycle
- if(TQDate::tqcurrentDate() < forecast.beginForecastDate()) {
- daysToBeginDay = TQDate::tqcurrentDate().daysTo(forecast.beginForecastDate());
+ if(TQDate::currentDate() < forecast.beginForecastDate()) {
+ daysToBeginDay = TQDate::currentDate().daysTo(forecast.beginForecastDate());
} else {
daysToBeginDay = forecast.accountsCycle();
}
@@ -205,8 +205,8 @@ void KMyMoneyAccountTreeForecastItem::updateSummary()
MyMoneyFile* file = MyMoneyFile::instance();
int daysToBeginDay;
- if(TQDate::tqcurrentDate() < m_forecast.beginForecastDate()) {
- daysToBeginDay = TQDate::tqcurrentDate().daysTo(m_forecast.beginForecastDate());
+ if(TQDate::currentDate() < m_forecast.beginForecastDate()) {
+ daysToBeginDay = TQDate::currentDate().daysTo(m_forecast.beginForecastDate());
} else {
daysToBeginDay = m_forecast.accountsCycle();
}
@@ -221,7 +221,7 @@ void KMyMoneyAccountTreeForecastItem::updateSummary()
//add current balance column
- TQDate summaryDate = TQDate::tqcurrentDate();
+ TQDate summaryDate = TQDate::currentDate();
amountMM = m_forecast.forecastBalance(m_account, summaryDate);
//calculate the balance in base currency for the total row
@@ -231,7 +231,7 @@ void KMyMoneyAccountTreeForecastItem::updateSummary()
it_c++;
//iterate through all other columns
- for(TQDate summaryDate = TQDate::tqcurrentDate().addDays(daysToBeginDay); summaryDate <= m_forecast.forecastEndDate();summaryDate = summaryDate.addDays(m_forecast.accountsCycle()), ++it_c) {
+ for(TQDate summaryDate = TQDate::currentDate().addDays(daysToBeginDay); summaryDate <= m_forecast.forecastEndDate();summaryDate = summaryDate.addDays(m_forecast.accountsCycle()), ++it_c) {
amountMM = m_forecast.forecastBalance(m_account, summaryDate);
//calculate the balance in base currency for the total row
@@ -263,7 +263,7 @@ void KMyMoneyAccountTreeForecastItem::updateDetailed()
int it_c = 1; // iterator for the columns of the listview
- for(TQDate forecastDate = TQDate::tqcurrentDate(); forecastDate <= m_forecast.forecastEndDate(); ++it_c, forecastDate = forecastDate.addDays(1)) {
+ for(TQDate forecastDate = TQDate::currentDate(); forecastDate <= m_forecast.forecastEndDate(); ++it_c, forecastDate = forecastDate.addDays(1)) {
MyMoneyMoney amountMM = m_forecast.forecastBalance(m_account, forecastDate);
//calculate the balance in base currency for the total row
diff --git a/kmymoney2/widgets/kmymoneybriefschedule.cpp b/kmymoney2/widgets/kmymoneybriefschedule.cpp
index a3e3a5f..5cb6348 100644
--- a/kmymoney2/widgets/kmymoneybriefschedule.cpp
+++ b/kmymoney2/widgets/kmymoneybriefschedule.cpp
@@ -47,8 +47,8 @@ KMyMoneyBriefSchedule::KMyMoneyBriefSchedule(TQWidget *parent, const char *name
: kScheduleBriefWidget(parent,name, WStyle_Customize | WStyle_NoBorder)
{
KIconLoader *ic = KGlobal::iconLoader();
- m_nextButton->setPixmap(BarIcon(TQString::tqfromLatin1("1rightarrow")));
- m_prevButton->setPixmap(BarIcon(TQString::tqfromLatin1("1leftarrow")));
+ m_nextButton->setPixmap(BarIcon(TQString::fromLatin1("1rightarrow")));
+ m_prevButton->setPixmap(BarIcon(TQString::fromLatin1("1leftarrow")));
connect(m_prevButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotPrevClicked()));
connect(m_nextButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotNextClicked()));
@@ -118,7 +118,7 @@ void KMyMoneyBriefSchedule::loadSchedule()
.tqarg(i18n(sched.occurenceToString()));
}
- if (m_date < TQDate::tqcurrentDate())
+ if (m_date < TQDate::currentDate())
{
if (sched.isOverdue())
{
@@ -129,8 +129,8 @@ void KMyMoneyBriefSchedule::loadSchedule()
if (m_date.isValid())
startD = m_date;
- int days = startD.daysTo(TQDate::tqcurrentDate());
- int transactions = sched.paymentDates(startD, TQDate::tqcurrentDate()).count();
+ int days = startD.daysTo(TQDate::currentDate());
+ int transactions = sched.paymentDates(startD, TQDate::currentDate()).count();
text += "<br><font color=red>";
text += i18n("%1 days overdue (%2 occurences).")
diff --git a/kmymoney2/widgets/kmymoneycalculator.cpp b/kmymoney2/widgets/kmymoneycalculator.cpp
index 1a117fa..adc51d2 100644
--- a/kmymoney2/widgets/kmymoneycalculator.cpp
+++ b/kmymoney2/widgets/kmymoneycalculator.cpp
@@ -50,7 +50,7 @@ kMyMoneyCalculator::kMyMoneyCalculator(TQWidget* parent, const char *name)
display->setBackgroundColor(TQColor("#BDFFB4"));
display->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
- display->tqsetAlignment(TQt::AlignRight | TQt::AlignVCenter);
+ display->setAlignment(TQt::AlignRight | TQt::AlignVCenter);
grid->addMultiCellWidget(display, 0, 0, 0, 4);
buttons[0] = new KPushButton("0", this);
diff --git a/kmymoney2/widgets/kmymoneycalendar.h b/kmymoney2/widgets/kmymoneycalendar.h
index 4b6f32d..a96a7c8 100644
--- a/kmymoney2/widgets/kmymoneycalendar.h
+++ b/kmymoney2/widgets/kmymoneycalendar.h
@@ -105,7 +105,7 @@ public:
* size hint, try adding 28 to each of the reported numbers of
* pixels.
**/
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
/**
* Sets the date.
@@ -144,7 +144,7 @@ public:
/**
* By calling this method with @p enable = true, KDatePicker will show
* a little close-button in the upper button-row. Clicking the
- * close-button will cause the KDatePicker's tqtopLevelWidget()'s close()
+ * close-button will cause the KDatePicker's topLevelWidget()'s close()
* method being called. This is mostly useful for toplevel datepickers
* without a window manager decoration.
* @see #hasCloseButton
diff --git a/kmymoney2/widgets/kmymoneycombo.cpp b/kmymoney2/widgets/kmymoneycombo.cpp
index 0d8ce4d..7146f68 100644
--- a/kmymoney2/widgets/kmymoneycombo.cpp
+++ b/kmymoney2/widgets/kmymoneycombo.cpp
@@ -131,12 +131,12 @@ void KMyMoneyCombo::paintEvent(TQPaintEvent* ev)
// is that length 1 is the blank case so no need to do painting
if(str.length() > 1) {
TQPainter p( this );
- const TQColorGroup & g = tqcolorGroup();
+ const TQColorGroup & g = colorGroup();
p.setPen(g.text());
TQRect re = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxEditField );
- re = TQStyle::tqvisualRect(re, this);
+ re = TQStyle::visualRect(re, this);
p.setClipRect( re );
p.save();
p.setFont(font());
@@ -182,7 +182,7 @@ bool KMyMoneyCombo::isInArrowArea(const TQPoint& pos) const
{
TQRect arrowRect = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxArrow);
- arrowRect = TQStyle::tqvisualRect(arrowRect, this);
+ arrowRect = TQStyle::visualRect(arrowRect, this);
// Correction for motif style, where arrow is smaller
// and thus has a rect that doesn't fit the button.
@@ -305,9 +305,9 @@ void KMyMoneyCombo::setSelectedItem(const TQString& id)
update();
}
-TQSize KMyMoneyCombo::tqsizeHint() const
+TQSize KMyMoneyCombo::sizeHint() const
{
- return KComboBox::tqsizeHint();
+ return KComboBox::sizeHint();
// I wanted to use the code below to adjust the size of the combo box
// according to the largest item in the selector list. Apparently that
@@ -325,11 +325,11 @@ TQSize KMyMoneyCombo::tqsizeHint() const
if ( w > maxW )
maxW = w;
- TQSize tqsizeHint = (style().sizeFromContents(TQStyle::CT_ComboBox, this,
+ TQSize sizeHint = (style().sizeFromContents(TQStyle::CT_ComboBox, this,
TQSize(maxW, maxH)).
expandedTo(TQApplication::globalStrut()));
- return tqsizeHint;
+ return sizeHint;
#endif
}
diff --git a/kmymoney2/widgets/kmymoneycombo.h b/kmymoney2/widgets/kmymoneycombo.h
index 32f4ec5..7581002 100644
--- a/kmymoney2/widgets/kmymoneycombo.h
+++ b/kmymoney2/widgets/kmymoneycombo.h
@@ -143,7 +143,7 @@ public:
/**
* Overridden to support our own completion box
*/
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
protected slots:
virtual void slotItemSelected(const TQString& id);
diff --git a/kmymoney2/widgets/kmymoneycompletion.cpp b/kmymoney2/widgets/kmymoneycompletion.cpp
index fbcc8a5..41fa082 100644
--- a/kmymoney2/widgets/kmymoneycompletion.cpp
+++ b/kmymoney2/widgets/kmymoneycompletion.cpp
@@ -76,7 +76,7 @@ void kMyMoneyCompletion::adjustSize(void)
void kMyMoneyCompletion::adjustSize(const int count)
{
- int w = m_widget->tqsizeHint().width();
+ int w = m_widget->sizeHint().width();
if(m_parent && w < m_parent->width())
w = m_parent->width();
diff --git a/kmymoney2/widgets/kmymoneydatetbl.cpp b/kmymoney2/widgets/kmymoneydatetbl.cpp
index ccff3c6..4007345 100644
--- a/kmymoney2/widgets/kmymoneydatetbl.cpp
+++ b/kmymoney2/widgets/kmymoneydatetbl.cpp
@@ -80,7 +80,7 @@ kMyMoneyDateTbl::kMyMoneyDateTbl(TQWidget *parent, TQDate date_, const char* nam
if(!date_.isValid())
{
kdDebug() << "kMyMoneyDateTbl ctor: WARNING: Given date is invalid, using current date." << endl;
- date_=TQDate::tqcurrentDate();
+ date_=TQDate::currentDate();
}
setFocusPolicy( TQ_StrongFocus );
@@ -307,7 +307,7 @@ kMyMoneyDateTbl::keyPressEvent( TQKeyEvent *e )
return;
}
if ( e->key() == TQt::Key_N ) {
- setDate(TQDate::tqcurrentDate());
+ setDate(TQDate::currentDate());
return;
}
@@ -352,7 +352,7 @@ kMyMoneyDateTbl::setFontSize(int size)
}
// ----- compare with a real wide number and add some space:
- rect=metrics.boundingRect(TQString::tqfromLatin1("88"));
+ rect=metrics.boundingRect(TQString::fromLatin1("88"));
maxCell.setWidth(TQMAX(maxCell.width()+2, rect.width()));
maxCell.setHeight(TQMAX(maxCell.height()+4, rect.height()));
}
@@ -517,14 +517,14 @@ void kMyMoneyDateTbl::focusOutEvent( TQFocusEvent *e )
}
TQSize
-kMyMoneyDateTbl::tqsizeHint() const
+kMyMoneyDateTbl::sizeHint() const
{
if (maxCell.height()>0 && maxCell.width()>0)
{
return TQSize(maxCell.width()*numCols()+2*frameWidth(),
(maxCell.height()+2)*numRows()+2*frameWidth());
} else {
- kdDebug() << "kMyMoneyDateTbl::tqsizeHint: obscure failure - " << endl;
+ kdDebug() << "kMyMoneyDateTbl::sizeHint: obscure failure - " << endl;
return TQSize(-1, -1);
}
}
diff --git a/kmymoney2/widgets/kmymoneyedit.cpp b/kmymoney2/widgets/kmymoneyedit.cpp
index 2cbb6b3..54affd2 100644
--- a/kmymoney2/widgets/kmymoneyedit.cpp
+++ b/kmymoney2/widgets/kmymoneyedit.cpp
@@ -211,7 +211,7 @@ void kMyMoneyEdit::init(void)
// Yes, just a simple double validator !
kMyMoneyMoneyValidator *validator = new kMyMoneyMoneyValidator(TQT_TQOBJECT(this));
m_edit->setValidator(validator);
- m_edit->tqsetAlignment(AlignRight | AlignVCenter);
+ m_edit->setAlignment(AlignRight | AlignVCenter);
m_calculatorFrame = new TQVBox(this, 0, WType_Popup);
@@ -223,15 +223,15 @@ void kMyMoneyEdit::init(void)
m_calculatorFrame->hide();
m_calcButton = new KPushButton(TQIconSet(TQPixmap(KGlobal::iconLoader()->iconPath("kcalc", -KIcon::SizeSmall))), TQString(""), this);
- m_calcButton->setFixedWidth( m_calcButton->tqsizeHint().width() );
- m_calcButton->setFixedHeight(m_edit->tqsizeHint().height());
+ m_calcButton->setFixedWidth( m_calcButton->sizeHint().width() );
+ m_calcButton->setFixedHeight(m_edit->sizeHint().height());
m_calcButton->setFocusProxy(m_edit);
TQPixmap pixmap;
pixmap.loadFromData(resetButtonImage, sizeof(resetButtonImage), "PNG", 0);
m_resetButton = new KPushButton(TQIconSet(pixmap), TQString(""), this);
- m_resetButton->setFixedWidth( m_resetButton->tqsizeHint().width() );
- m_resetButton->setFixedHeight(m_edit->tqsizeHint().height());
+ m_resetButton->setFixedWidth( m_resetButton->sizeHint().width() );
+ m_resetButton->setFixedHeight(m_edit->sizeHint().height());
m_resetButton->setEnabled(false);
m_resetButton->setFocusProxy(m_edit);
@@ -496,7 +496,7 @@ void kMyMoneyEdit::slotCalculatorResult(void)
}
}
-TQWidget* kMyMoneyEdit::tqfocusWidget(void) const
+TQWidget* kMyMoneyEdit::focusWidget(void) const
{
TQWidget* w = m_edit;
while(w->focusProxy())
diff --git a/kmymoney2/widgets/kmymoneyedit.h b/kmymoney2/widgets/kmymoneyedit.h
index 3aaacd1..2aeea47 100644
--- a/kmymoney2/widgets/kmymoneyedit.h
+++ b/kmymoney2/widgets/kmymoneyedit.h
@@ -184,7 +184,7 @@ public:
*/
int precision(void) { return m_prec; };
- TQWidget* tqfocusWidget(void) const;
+ TQWidget* focusWidget(void) const;
/**
* This method allows to modify the behavior of the widget
diff --git a/kmymoney2/widgets/kmymoneygpgconfigdecl.ui b/kmymoney2/widgets/kmymoneygpgconfigdecl.ui
index fd8efbc..ec3c34c 100644
--- a/kmymoney2/widgets/kmymoneygpgconfigdecl.ui
+++ b/kmymoney2/widgets/kmymoneygpgconfigdecl.ui
@@ -133,7 +133,7 @@ The &lt;i&gt;Recovery encryption&lt;/i&gt; group is only accessible, if the nece
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>51</width>
<height>20</height>
@@ -184,7 +184,7 @@ This mechanism is provided for the case that you have lost your key and cannot a
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>16</height>
diff --git a/kmymoney2/widgets/kmymoneylineedit.cpp b/kmymoney2/widgets/kmymoneylineedit.cpp
index 2250c30..53cb3a5 100644
--- a/kmymoney2/widgets/kmymoneylineedit.cpp
+++ b/kmymoney2/widgets/kmymoneylineedit.cpp
@@ -39,7 +39,7 @@ kMyMoneyLineEdit::kMyMoneyLineEdit(TQWidget *w, const char* name, bool forceMone
KLineEdit(w, name),
m_forceMonetaryDecimalSymbol(forceMonetaryDecimalSymbol)
{
- tqsetAlignment(tqalignment);
+ setAlignment(tqalignment);
}
kMyMoneyLineEdit::~kMyMoneyLineEdit()
diff --git a/kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui b/kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui
index 2392f80..9e11973 100644
--- a/kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui
+++ b/kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui
@@ -12,7 +12,7 @@
<height>487</height>
</rect>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -206,7 +206,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>240</width>
<height>20</height>
diff --git a/kmymoney2/widgets/kmymoneyreportconfigtab1decl.ui b/kmymoney2/widgets/kmymoneyreportconfigtab1decl.ui
index 4a84ee7..9081a17 100644
--- a/kmymoney2/widgets/kmymoneyreportconfigtab1decl.ui
+++ b/kmymoney2/widgets/kmymoneyreportconfigtab1decl.ui
@@ -110,7 +110,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kmymoney2/widgets/kmymoneyreportconfigtab2decl.ui b/kmymoney2/widgets/kmymoneyreportconfigtab2decl.ui
index 04b6e71..a847537 100644
--- a/kmymoney2/widgets/kmymoneyreportconfigtab2decl.ui
+++ b/kmymoney2/widgets/kmymoneyreportconfigtab2decl.ui
@@ -226,7 +226,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>94</width>
<height>21</height>
@@ -269,7 +269,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
diff --git a/kmymoney2/widgets/kmymoneyreportconfigtab3decl.ui b/kmymoney2/widgets/kmymoneyreportconfigtab3decl.ui
index 6b23280..4e3cc5b 100644
--- a/kmymoney2/widgets/kmymoneyreportconfigtab3decl.ui
+++ b/kmymoney2/widgets/kmymoneyreportconfigtab3decl.ui
@@ -125,7 +125,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>358</width>
<height>16</height>
@@ -174,7 +174,7 @@
<property name="name">
<cstring>m_checkMemo</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -235,7 +235,7 @@
<property name="name">
<cstring>m_checkNumber</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -252,7 +252,7 @@
<property name="name">
<cstring>m_checkPayee</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -269,7 +269,7 @@
<property name="name">
<cstring>m_checkCategory</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -316,7 +316,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>205</width>
<height>20</height>
@@ -386,7 +386,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/kmymoney2/widgets/kmymoneyreportconfigtabchartdecl.ui b/kmymoney2/widgets/kmymoneyreportconfigtabchartdecl.ui
index 452e69c..7f8bdd7 100644
--- a/kmymoney2/widgets/kmymoneyreportconfigtabchartdecl.ui
+++ b/kmymoney2/widgets/kmymoneyreportconfigtabchartdecl.ui
@@ -92,7 +92,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>121</width>
<height>20</height>
@@ -182,7 +182,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>121</width>
<height>20</height>
@@ -201,7 +201,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kmymoney2/widgets/kmymoneyreportcontroldecl.ui b/kmymoney2/widgets/kmymoneyreportcontroldecl.ui
index 00ba7e0..d13da36 100644
--- a/kmymoney2/widgets/kmymoneyreportcontroldecl.ui
+++ b/kmymoney2/widgets/kmymoneyreportcontroldecl.ui
@@ -29,7 +29,7 @@
<property name="name">
<cstring>buttonChart</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>75</width>
<height>0</height>
@@ -46,7 +46,7 @@
<property name="name">
<cstring>buttonConfigure</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>75</width>
<height>0</height>
@@ -63,7 +63,7 @@
<property name="name">
<cstring>buttonNew</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>75</width>
<height>0</height>
@@ -80,7 +80,7 @@
<property name="name">
<cstring>buttonCopy</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>75</width>
<height>0</height>
@@ -97,7 +97,7 @@
<property name="name">
<cstring>buttonExport</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>75</width>
<height>0</height>
@@ -114,7 +114,7 @@
<property name="name">
<cstring>buttonDelete</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>75</width>
<height>0</height>
@@ -131,7 +131,7 @@
<property name="name">
<cstring>buttonClose</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>75</width>
<height>0</height>
diff --git a/kmymoney2/widgets/kmymoneyscheduledcalendar.cpp b/kmymoney2/widgets/kmymoneyscheduledcalendar.cpp
index 4599eb5..9f6d131 100644
--- a/kmymoney2/widgets/kmymoneyscheduledcalendar.cpp
+++ b/kmymoney2/widgets/kmymoneyscheduledcalendar.cpp
@@ -59,7 +59,7 @@ kMyMoneyScheduledCalendar::kMyMoneyScheduledCalendar(TQWidget *parent, const cha
setUserButton1(true, pb1);
- init( TQDate::tqcurrentDate() );
+ init( TQDate::currentDate() );
connect(m_scheduledDateTable, TQT_SIGNAL(enterClicked(const MyMoneySchedule&, const TQDate&)),
this, TQT_SIGNAL(enterClicked(const MyMoneySchedule&, const TQDate&)));
diff --git a/kmymoney2/widgets/kmymoneyscheduleddatetbl.cpp b/kmymoney2/widgets/kmymoneyscheduleddatetbl.cpp
index 5562d31..7d203fa 100644
--- a/kmymoney2/widgets/kmymoneyscheduleddatetbl.cpp
+++ b/kmymoney2/widgets/kmymoneyscheduleddatetbl.cpp
@@ -176,7 +176,7 @@ void kMyMoneyScheduledDateTbl::drawCellContents(TQPainter *painter, int /*row*/,
for (iter=schedules.begin(); iter!=schedules.end(); ++iter)
{
MyMoneySchedule schedule = *iter;
- if (theDate < TQDate::tqcurrentDate())
+ if (theDate < TQDate::currentDate())
{
if (schedule.isOverdue())
{
@@ -286,7 +286,7 @@ void kMyMoneyScheduledDateTbl::drawCellContents(TQPainter *painter, int /*row*/,
for (iter=transferSchedules.begin(); iter!=transferSchedules.end(); ++iter)
{
MyMoneySchedule schedule = *iter;
- if (theDate < TQDate::tqcurrentDate())
+ if (theDate < TQDate::currentDate())
{
if (schedule.isOverdue())
{
@@ -301,7 +301,7 @@ void kMyMoneyScheduledDateTbl::drawCellContents(TQPainter *painter, int /*row*/,
for (iter=depositSchedules.begin(); iter!=depositSchedules.end(); ++iter)
{
MyMoneySchedule schedule = *iter;
- if (theDate < TQDate::tqcurrentDate())
+ if (theDate < TQDate::currentDate())
{
if (schedule.isOverdue())
{
@@ -316,7 +316,7 @@ void kMyMoneyScheduledDateTbl::drawCellContents(TQPainter *painter, int /*row*/,
for (iter=billSchedules.begin(); iter!=billSchedules.end(); ++iter)
{
MyMoneySchedule schedule = *iter;
- if (theDate < TQDate::tqcurrentDate())
+ if (theDate < TQDate::currentDate())
{
if (schedule.isOverdue())
{
diff --git a/kmymoney2/widgets/kmymoneyscheduleddatetbl.h b/kmymoney2/widgets/kmymoneyscheduleddatetbl.h
index e607ad0..f2b9c27 100644
--- a/kmymoney2/widgets/kmymoneyscheduleddatetbl.h
+++ b/kmymoney2/widgets/kmymoneyscheduleddatetbl.h
@@ -46,7 +46,7 @@ class kMyMoneyScheduledDateTbl : public kMyMoneyDateTbl
TQ_OBJECT
public:
kMyMoneyScheduledDateTbl(TQWidget *parent=0,
- TQDate date=TQDate::tqcurrentDate(),
+ TQDate date=TQDate::currentDate(),
const char* name=0, WFlags f=0);
~kMyMoneyScheduledDateTbl();
diff --git a/kmymoney2/widgets/kmymoneyselector.cpp b/kmymoney2/widgets/kmymoneyselector.cpp
index 17428ce..daf7991 100644
--- a/kmymoney2/widgets/kmymoneyselector.cpp
+++ b/kmymoney2/widgets/kmymoneyselector.cpp
@@ -661,7 +661,7 @@ void KMyMoneySelector::slotListRightMouse(TQListViewItem* it_v, const TQPoint& p
KMyMoneyCheckListItem* it_c = static_cast<KMyMoneyCheckListItem*>(it_v);
if(it_c->type() == TQCheckListItem::CheckBox) {
// the following is copied from TQCheckListItem::activate() et al
- int boxsize = m_listView->tqstyle().tqpixelMetric(TQStyle::PM_CheckListButtonSize, m_listView);
+ int boxsize = m_listView->tqstyle().pixelMetric(TQStyle::PM_CheckListButtonSize, m_listView);
int align = m_listView->columnAlignment( 0 );
int marg = m_listView->itemMargin();
int y = 0;
@@ -675,7 +675,7 @@ void KMyMoneySelector::slotListRightMouse(TQListViewItem* it_v, const TQPoint& p
// columns might have been swapped
r.moveBy( m_listView->header()->sectionPos( 0 ), 0 );
- TQPoint topLeft = m_listView->tqitemRect(it_v).topLeft(); //### inefficient?
+ TQPoint topLeft = m_listView->itemRect(it_v).topLeft(); //### inefficient?
TQPoint p = m_listView->mapFromGlobal( pos ) - topLeft;
int xdepth = m_listView->treeStepSize() * (it_v->depth() + (m_listView->rootIsDecorated() ? 1 : 0))
diff --git a/kmymoney2/widgets/kmymoneytitlelabel.cpp b/kmymoney2/widgets/kmymoneytitlelabel.cpp
index db3dba2..5cf561c 100644
--- a/kmymoney2/widgets/kmymoneytitlelabel.cpp
+++ b/kmymoney2/widgets/kmymoneytitlelabel.cpp
@@ -91,7 +91,7 @@ void KMyMoneyTitleLabel::drawContents(TQPainter *p)
TQLabel::drawContents(p);
// then draw text on top
- tqstyle().drawItem( p, contentsRect(), tqalignment(), tqcolorGroup(), isEnabled(),
+ tqstyle().drawItem( p, contentsRect(), tqalignment(), colorGroup(), isEnabled(),
0, TQString(" ")+m_text, -1, &m_textColor );
}
diff --git a/kmymoney2/widgets/kmymoneywizard.cpp b/kmymoney2/widgets/kmymoneywizard.cpp
index 0c038bc..aeef106 100644
--- a/kmymoney2/widgets/kmymoneywizard.cpp
+++ b/kmymoney2/widgets/kmymoneywizard.cpp
@@ -155,7 +155,7 @@ KMyMoneyWizard::KMyMoneyWizard(TQWidget *parent, const char *name, bool modal, W
m_stepLayout->addWidget(new TQLabel("", m_stepFrame));
m_stepLayout->addItem(new TQSpacerItem(20, 20, TQSizePolicy::Minimum, TQSizePolicy::Expanding));
m_stepLabel = new TQLabel(m_stepFrame, "stepLabel");
- m_stepLabel->tqsetAlignment(TQt::AlignHCenter);
+ m_stepLabel->setAlignment(TQt::AlignHCenter);
m_stepLayout->addWidget(m_stepLabel);
hboxLayout->addWidget(m_stepFrame);
@@ -183,7 +183,7 @@ KMyMoneyWizard::KMyMoneyWizard(TQWidget *parent, const char *name, bool modal, W
hboxLayout->addLayout(m_pageLayout);
m_wizardLayout->addLayout(hboxLayout);
- resize(TQSize(770, 520).expandedTo(tqminimumSizeHint()));
+ resize(TQSize(770, 520).expandedTo(minimumSizeHint()));
clearWState(WState_Polished);
m_titleLabel->setText("No Title specified");
@@ -207,7 +207,7 @@ void KMyMoneyWizard::addStep(const TQString& text)
{
TQLabel* step = new TQLabel(text, m_stepFrame);
step->setFrameStyle(TQFrame::Panel | TQFrame::Raised);
- step->tqsetAlignment(TQt::AlignHCenter);
+ step->setAlignment(TQt::AlignHCenter);
step->setFrameStyle(TQFrame::Box | TQFrame::Sunken);
step->setMargin(2);
step->setPalette( m_stepPalette );
diff --git a/kmymoney2/widgets/kschedulebriefwidget.ui b/kmymoney2/widgets/kschedulebriefwidget.ui
index 209e727..29f5b75 100644
--- a/kmymoney2/widgets/kschedulebriefwidget.ui
+++ b/kmymoney2/widgets/kschedulebriefwidget.ui
@@ -86,7 +86,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>0</height>
@@ -111,7 +111,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>70</width>
<height>0</height>
@@ -140,13 +140,13 @@
<property name="name">
<cstring>textLabel1</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>60</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -160,13 +160,13 @@
<property name="name">
<cstring>textLabel2</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>60</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -221,7 +221,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>60</width>
<height>0</height>
@@ -274,7 +274,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>35</width>
<height>0</height>
@@ -334,7 +334,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>43</width>
<height>0</height>
diff --git a/kmymoney2/widgets/register.cpp b/kmymoney2/widgets/register.cpp
index b01513e..93277cf 100644
--- a/kmymoney2/widgets/register.cpp
+++ b/kmymoney2/widgets/register.cpp
@@ -1292,9 +1292,9 @@ void Register::resize(int col)
kMyMoneyEdit* valField = new kMyMoneyEdit;
dateField->setFont(KMyMoneyGlobalSettings::listCellFont());
- setColumnWidth(DateColumn, dateField->tqminimumSizeHint().width());
+ setColumnWidth(DateColumn, dateField->minimumSizeHint().width());
valField->setMinimumWidth(ewidth);
- ewidth = valField->tqminimumSizeHint().width();
+ ewidth = valField->minimumSizeHint().width();
if(swidth > 0) {
swidth = columnWidth(SecurityColumn) + 40;
@@ -2265,7 +2265,7 @@ void Register::addGroupMarkers(void)
switch(primarySortKey()) {
case KMyMoneyRegister::PostDateSort:
case KMyMoneyRegister::EntryDateSort:
- today = TQDate::tqcurrentDate();
+ today = TQDate::currentDate();
thisMonth.setYMD(today.year(), today.month(), 1);
lastMonth = thisMonth.addMonths(-1);
yesterday = today.addDays(-1);
@@ -2309,9 +2309,9 @@ void Register::addGroupMarkers(void)
new KMyMoneyRegister::SimpleDateGroupMarker(this, today.addDays(1), i18n("Future transactions"));
}
if(KMyMoneyGlobalSettings::showFiscalMarker()) {
- TQDate currentFiscalYear(TQDate::tqcurrentDate().year(), KMyMoneyGlobalSettings::firstFiscalMonth(), KMyMoneyGlobalSettings::firstFiscalDay());
+ TQDate currentFiscalYear(TQDate::currentDate().year(), KMyMoneyGlobalSettings::firstFiscalMonth(), KMyMoneyGlobalSettings::firstFiscalDay());
- if(TQDate::tqcurrentDate() < currentFiscalYear)
+ if(TQDate::currentDate() < currentFiscalYear)
currentFiscalYear = currentFiscalYear.addYears(-1);
TQDate previousFiscalYear = currentFiscalYear.addYears(-1);
new KMyMoneyRegister::FiscalYearGroupMarker(this, currentFiscalYear, i18n("Current fiscal year"));
diff --git a/kmymoney2/widgets/transaction.cpp b/kmymoney2/widgets/transaction.cpp
index 5811a8c..8afc4e4 100644
--- a/kmymoney2/widgets/transaction.cpp
+++ b/kmymoney2/widgets/transaction.cpp
@@ -508,7 +508,7 @@ int Transaction::formRowHeight(void) const
kMyMoneyDateInput dateInput;
KMyMoneyCategory category(0,0,true);
- return TQMAX(dateInput.tqsizeHint().height(), category.tqsizeHint().height());
+ return TQMAX(dateInput.sizeHint().height(), category.sizeHint().height());
}
return m_formRowHeight;
}
@@ -598,7 +598,7 @@ void Transaction::setupRegisterPalette(TQMap<TQString, TQWidget*>& editWidgets)
setupPalette(palette, editWidgets);
}
-TQWidget* Transaction::tqfocusWidget(TQWidget* w) const
+TQWidget* Transaction::focusWidget(TQWidget* w) const
{
if(w) {
while(w->focusProxy())
@@ -1253,34 +1253,34 @@ void StdTransaction::tabOrderInForm(TQWidgetList& tabOrderWidgets) const
TQWidget* w;
while(it_s != taborder.constEnd()) {
if(*it_s == "account") {
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(0, ValueColumn1)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(0, ValueColumn1)));
} else if(*it_s == "cashflow") {
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(1, LabelColumn1)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(1, LabelColumn1)));
} else if(*it_s == "payee") {
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(1, ValueColumn1)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(1, ValueColumn1)));
} else if(*it_s == "category") {
// make sure to have the category field and the split button as seperate tab order widgets
// ok, we have to have some internal knowledge about the KMyMoneyCategory object, but
// it's one of our own widgets, so we actually don't care. Just make sure, that we don't
// go haywire when someone changes the KMyMoneyCategory object ...
w = m_form->cellWidget(2, ValueColumn1);
- tabOrderWidgets.append(tqfocusWidget(w));
+ tabOrderWidgets.append(focusWidget(w));
w = dynamic_cast<TQWidget*>(w->child("splitButton"));
if(w)
tabOrderWidgets.append(w);
} else if(*it_s == "memo") {
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(3, ValueColumn1)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(3, ValueColumn1)));
} else if(*it_s == "number") {
if(haveNumberField()) {
- if((w = tqfocusWidget(m_form->cellWidget(1, ValueColumn2))))
+ if((w = focusWidget(m_form->cellWidget(1, ValueColumn2))))
tabOrderWidgets.append(w);
}
} else if(*it_s == "date") {
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(2, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(2, ValueColumn2)));
} else if(*it_s == "amount") {
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(3, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(3, ValueColumn2)));
} else if(*it_s == "state") {
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(5, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(5, ValueColumn2)));
}
++it_s;
}
@@ -1315,31 +1315,31 @@ void StdTransaction::tabOrderInRegister(TQWidgetList& tabOrderWidgets) const
while(it_s != taborder.constEnd()) {
if(*it_s == "number") {
if(haveNumberField()) {
- if((w = tqfocusWidget(m_parent->cellWidget(m_startRow + 0, NumberColumn))))
+ if((w = focusWidget(m_parent->cellWidget(m_startRow + 0, NumberColumn))))
tabOrderWidgets.append(w);
}
} else if(*it_s == "date") {
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 0, DateColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DateColumn)));
} else if(*it_s == "payee") {
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 0, DetailColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DetailColumn)));
} else if(*it_s == "category") {
// make sure to have the category field and the split button as seperate tab order widgets
// ok, we have to have some internal knowledge about the KMyMoneyCategory object, but
// it's one of our own widgets, so we actually don't care. Just make sure, that we don't
// go haywire when someone changes the KMyMoneyCategory object ...
w = m_parent->cellWidget(m_startRow + 1, DetailColumn);
- tabOrderWidgets.append(tqfocusWidget(w));
+ tabOrderWidgets.append(focusWidget(w));
w = dynamic_cast<TQWidget*>(w->child("splitButton"));
if(w)
tabOrderWidgets.append(w);
} else if(*it_s == "memo") {
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 2, DetailColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 2, DetailColumn)));
} else if(*it_s == "payment") {
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 0, PaymentColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, PaymentColumn)));
} else if(*it_s == "deposit") {
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 0, DepositColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DepositColumn)));
} else if(*it_s == "state") {
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 1, DateColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 1, DateColumn)));
}
++it_s;
}
@@ -1929,54 +1929,54 @@ void InvestTransaction::arrangeWidgetsInForm(TQMap<TQString, TQWidget*>& editWid
void InvestTransaction::tabOrderInForm(TQWidgetList& tabOrderWidgets) const
{
// activity
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(0, ValueColumn1)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(0, ValueColumn1)));
// date
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(0, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(0, ValueColumn2)));
// security
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(1, ValueColumn1)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(1, ValueColumn1)));
// shares
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(1, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(1, ValueColumn2)));
// account
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(2, ValueColumn1)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(2, ValueColumn1)));
// price
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(2, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(2, ValueColumn2)));
// make sure to have the fee category field and the split button as seperate tab order widgets
// ok, we have to have some internal knowledge about the KMyMoneyCategory object, but
// it's one of our own widgets, so we actually don't care. Just make sure, that we don't
// go haywire when someone changes the KMyMoneyCategory object ...
TQWidget* w = m_form->cellWidget(3, ValueColumn1);
- tabOrderWidgets.append(tqfocusWidget(w));
+ tabOrderWidgets.append(focusWidget(w));
w = dynamic_cast<TQWidget*>(w->child("splitButton"));
if(w)
tabOrderWidgets.append(w);
// fee amount
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(3, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(3, ValueColumn2)));
// the same applies for the interest categories
w = m_form->cellWidget(4, ValueColumn1);
- tabOrderWidgets.append(tqfocusWidget(w));
+ tabOrderWidgets.append(focusWidget(w));
w = dynamic_cast<TQWidget*>(w->child("splitButton"));
if(w)
tabOrderWidgets.append(w);
// interest amount
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(4, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(4, ValueColumn2)));
// memo
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(5, ValueColumn1)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(5, ValueColumn1)));
// total
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(5, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(5, ValueColumn2)));
// state
- tabOrderWidgets.append(tqfocusWidget(m_form->cellWidget(6, ValueColumn2)));
+ tabOrderWidgets.append(focusWidget(m_form->cellWidget(6, ValueColumn2)));
}
void InvestTransaction::arrangeWidgetsInRegister(TQMap<TQString, TQWidget*>& editWidgets)
@@ -2009,45 +2009,45 @@ void InvestTransaction::tabOrderInRegister(TQWidgetList& tabOrderWidgets) const
TQWidget* w;
// date
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 0, DateColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DateColumn)));
// security
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 0, SecurityColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, SecurityColumn)));
// activity
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 0, DetailColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DetailColumn)));
// shares
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 0, QuantityColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, QuantityColumn)));
// price
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 0, PriceColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, PriceColumn)));
// asset account
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 1, DetailColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 1, DetailColumn)));
// make sure to have the category fields and the split button as seperate tab order widgets
// ok, we have to have some internal knowledge about the KMyMoneyCategory object, but
// it's one of our own widgets, so we actually don't care. Just make sure, that we don't
// go haywire when someone changes the KMyMoneyCategory object ...
w = m_parent->cellWidget(m_startRow + 2, DetailColumn); // interest account
- tabOrderWidgets.append(tqfocusWidget(w));
+ tabOrderWidgets.append(focusWidget(w));
w = dynamic_cast<TQWidget*>(w->child("splitButton"));
if(w)
tabOrderWidgets.append(w);
// interest amount
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 2, QuantityColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 2, QuantityColumn)));
w = m_parent->cellWidget(m_startRow + 3, DetailColumn); // fee account
- tabOrderWidgets.append(tqfocusWidget(w));
+ tabOrderWidgets.append(focusWidget(w));
w = dynamic_cast<TQWidget*>(w->child("splitButton"));
if(w)
tabOrderWidgets.append(w);
// fee amount
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 3, QuantityColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 3, QuantityColumn)));
// memo
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 4, DetailColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 4, DetailColumn)));
// status
- tabOrderWidgets.append(tqfocusWidget(m_parent->cellWidget(m_startRow + 1, DateColumn)));
+ tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 1, DateColumn)));
}
int InvestTransaction::numRowsRegister(bool expanded) const
diff --git a/kmymoney2/widgets/transaction.h b/kmymoney2/widgets/transaction.h
index a24c864..8abc217 100644
--- a/kmymoney2/widgets/transaction.h
+++ b/kmymoney2/widgets/transaction.h
@@ -183,7 +183,7 @@ public:
virtual KMyMoneyRegister::Action actionType(void) const = 0;
- TQWidget* tqfocusWidget(TQWidget*) const;
+ TQWidget* focusWidget(TQWidget*) const;
void arrangeWidget(TQTable* tbl, int row, int col, TQWidget* w) const;
bool haveNumberField(void) const;
diff --git a/kmymoney2/widgets/transactionform.h b/kmymoney2/widgets/transactionform.h
index f07a1e4..c85a713 100644
--- a/kmymoney2/widgets/transactionform.h
+++ b/kmymoney2/widgets/transactionform.h
@@ -135,7 +135,7 @@ public:
void paintFocus(TQPainter* /*p*/, const TQRect& /*cr*/ ) {}
TQSize tableSize(void) const;
- TQSize tqsizeHint(void) const;
+ TQSize sizeHint(void) const;
void adjustColumn(Column col);
void clear(void);
diff --git a/kmymoney2/widgets/transactionsortoption.ui b/kmymoney2/widgets/transactionsortoption.ui
index fc91754..8a85462 100644
--- a/kmymoney2/widgets/transactionsortoption.ui
+++ b/kmymoney2/widgets/transactionsortoption.ui
@@ -73,7 +73,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>67</height>
@@ -106,7 +106,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>67</height>
@@ -168,7 +168,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>67</height>
@@ -201,7 +201,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>67</height>
diff --git a/kmymoney2/widgets/kmymoneycalendar.cpp b/kmymoney2/widgets/kmymoneycalendar.cpp
index 664548d..4c824c8 100644
--- a/kmymoney2/widgets/kmymoneycalendar.cpp
+++ b/kmymoney2/widgets/kmymoneycalendar.cpp
@@ -138,10 +138,10 @@ void kMyMoneyCalendar::init( const TQDate &dt )
setFontSize(10);
line->setValidator(val);
line->installEventFilter( this );
- yearForward->setPixmap(BarIcon(TQString::tqfromLatin1("2rightarrow")));
- yearBackward->setPixmap(BarIcon(TQString::tqfromLatin1("2leftarrow")));
- monthForward->setPixmap(BarIcon(TQString::tqfromLatin1("1rightarrow")));
- monthBackward->setPixmap(BarIcon(TQString::tqfromLatin1("1leftarrow")));
+ yearForward->setPixmap(BarIcon(TQString::fromLatin1("2rightarrow")));
+ yearBackward->setPixmap(BarIcon(TQString::fromLatin1("2leftarrow")));
+ monthForward->setPixmap(BarIcon(TQString::fromLatin1("1rightarrow")));
+ monthBackward->setPixmap(BarIcon(TQString::fromLatin1("1leftarrow")));
setDate(dt); // set button texts
connect(table, TQT_SIGNAL(dateChanged(TQDate)), TQT_SLOT(dateChangedSlot(TQDate)));
connect(table, TQT_SIGNAL(tableClicked()), TQT_SLOT(tableClickedSlot()));
@@ -200,7 +200,7 @@ kMyMoneyCalendar::resizeEvent(TQResizeEvent*)
// ----- calculate button row height:
for(count=0; count<NoOfButtons; ++count) {
if ( buttons[count] ) { // closeButton may be 0L
- sizes[count]=buttons[count]->tqsizeHint();
+ sizes[count]=buttons[count]->sizeHint();
buttonHeight=TQMAX(buttonHeight, sizes[count].height());
}
else
@@ -211,7 +211,7 @@ kMyMoneyCalendar::resizeEvent(TQResizeEvent*)
for(count=0; count<NoOfButtons; ++count) {
if(buttons[count]==selectMonth) {
TQSize metricBound = tqstyle().tqsizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
- sizes[count].setWidth(TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::tqstyle().tqpixelMetric(TQStyle::PM_ButtonMargin)));
+ sizes[count].setWidth(TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::tqstyle().pixelMetric(TQStyle::PM_ButtonMargin)));
}
}
// ----- place the buttons:
@@ -245,7 +245,7 @@ kMyMoneyCalendar::resizeEvent(TQResizeEvent*)
}
// ----- place the line edit for direct input:
- sizes[0]=line->tqsizeHint();
+ sizes[0]=line->sizeHint();
int week_width=d->selectWeek->fontMetrics().width(i18n("Week XX"))+((d->closeButton != 0L) ? 50 : 20);
line->setGeometry(0, height()-sizes[0].height(), width()-week_width, sizes[0].height());
d->selectWeek->setGeometry(width()-week_width, height()-sizes[0].height(), week_width, sizes[0].height());
@@ -341,7 +341,7 @@ kMyMoneyCalendar::selectWeekClicked()
KPopupFrame* popup = new KPopupFrame(this);
KDateInternalWeekSelector* picker = new KDateInternalWeekSelector(/*fontsize, */popup);
// -----
- picker->resize(picker->tqsizeHint());
+ picker->resize(picker->sizeHint());
popup->setMainWidget(picker);
connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
picker->setFocus();
@@ -380,7 +380,7 @@ kMyMoneyCalendar::selectMonthClicked()
KPopupFrame* popup = new KPopupFrame(this);
KDateInternalMonthPicker* picker = new KDateInternalMonthPicker(/*fontsize, */popup);
// -----
- picker->resize(picker->tqsizeHint());
+ picker->resize(picker->sizeHint());
popup->setMainWidget(picker);
picker->setFocus();
connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
@@ -412,7 +412,7 @@ kMyMoneyCalendar::selectYearClicked()
KPopupFrame* popup = new KPopupFrame(this);
KDateInternalYearSelector* picker = new KDateInternalYearSelector(fontsize, popup);
// -----
- picker->resize(picker->tqsizeHint());
+ picker->resize(picker->sizeHint());
popup->setMainWidget(picker);
connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
picker->setFocus();
@@ -470,9 +470,9 @@ kMyMoneyCalendar::lineEnterPressed()
}
TQSize
-kMyMoneyCalendar::tqsizeHint() const
+kMyMoneyCalendar::sizeHint() const
{
- TQSize tableSize=table->tqsizeHint();
+ TQSize tableSize=table->sizeHint();
TQWidget *buttons[]={
styleControl,
yearBackward,
@@ -492,14 +492,14 @@ kMyMoneyCalendar::tqsizeHint() const
for(count=0; count<NoOfButtons; ++count)
{
if ( buttons[count] )
- sizes[count]=buttons[count]->tqsizeHint();
+ sizes[count]=buttons[count]->sizeHint();
else
sizes[count] = TQSize(0,0);
if(buttons[count]==selectMonth)
{
TQSize metricBound = tqstyle().tqsizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
- cx+=TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::tqstyle().tqpixelMetric(TQStyle::PM_ButtonMargin));
+ cx+=TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::tqstyle().pixelMetric(TQStyle::PM_ButtonMargin));
} else {
cx+=sizes[count].width();
}
@@ -508,7 +508,7 @@ kMyMoneyCalendar::tqsizeHint() const
// ----- calculate width hint:
cx=TQMAX(cx, tableSize.width()); // line edit ignored
// ----- calculate height hint:
- cy+=tableSize.height()+line->tqsizeHint().height();
+ cy+=tableSize.height()+line->sizeHint().height();
return TQSize(cx, cy);
}
@@ -540,7 +540,7 @@ kMyMoneyCalendar::setFontSize(int s)
}
TQFontMetrics metrics(selectMonth->fontMetrics());
for(int i=1; i <= 12; ++i)
- { // maxMonthRect is used by tqsizeHint()
+ { // maxMonthRect is used by sizeHint()
r=metrics.boundingRect(MONTH_NAME(i, 2000, false));
maxMonthRect.setWidth(TQMAX(r.width(), maxMonthRect.width()));
maxMonthRect.setHeight(TQMAX(r.height(), maxMonthRect.height()));
@@ -560,7 +560,7 @@ kMyMoneyCalendar::setCloseButton( bool enable )
TQToolTip::add(d->closeButton, i18n("Close"));
d->closeButton->setPixmap( SmallIcon("remove") );
connect( d->closeButton, TQT_SIGNAL( clicked() ),
- tqtopLevelWidget(), TQT_SLOT( close() ) );
+ topLevelWidget(), TQT_SLOT( close() ) );
}
else {
delete d->closeButton;
diff --git a/kmymoney2/widgets/kmymoneydateinput.cpp b/kmymoney2/widgets/kmymoneydateinput.cpp
index 37db28b..3362a15 100644
--- a/kmymoney2/widgets/kmymoneydateinput.cpp
+++ b/kmymoney2/widgets/kmymoneydateinput.cpp
@@ -73,11 +73,11 @@ kMyMoneyDateInput::kMyMoneyDateInput(TQWidget *parent, const char *name, TQt::Al
: TQHBox(parent,name)
{
m_qttqalignment = flags;
- m_date = TQDate::tqcurrentDate();
+ m_date = TQDate::currentDate();
dateEdit = new KMyMoneyDateEdit(m_date, this, "dateEdit");
setFocusProxy(dateEdit);
- tqfocusWidget()->installEventFilter(this); // To get dateEdit's FocusIn/Out and some KeyPress events
+ focusWidget()->installEventFilter(this); // To get dateEdit's FocusIn/Out and some KeyPress events
dateEdit->installEventFilter(this); // To get dateEdit's FocusIn/Out and some KeyPress events
m_datePopup = new KPassivePopup(dateEdit, "datePopup");
@@ -165,13 +165,13 @@ void kMyMoneyDateInput::show(void)
void kMyMoneyDateInput::fixSize(void)
{
// According to a hint in the documentation of KDatePicker::tqsizeHint()
// 28 pixels should be added in each direction to obtain a better
// display of the month button. I decided, (22,14) is good
// enough and save some space on the screen (ipwizard)
- m_dateFrame->setFixedSize(m_datePicker->tqsizeHint() + TQSize(22, 14));
+ m_dateFrame->setFixedSize(m_datePicker->sizeHint() + TQSize(22, 14));
- dateEdit->setMinimumWidth(dateEdit->tqminimumSizeHint().width() + 6);
+ dateEdit->setMinimumWidth(dateEdit->minimumSizeHint().width() + 6);
}
kMyMoneyDateInput::~kMyMoneyDateInput()
@@ -217,7 +217,7 @@ void kMyMoneyDateInput::toggleDatePicker()
}
else
{
- m_datePicker->setDate(TQDate::tqcurrentDate());
+ m_datePicker->setDate(TQDate::currentDate());
}
m_dateFrame->show();
}
@@ -255,14 +255,14 @@ void kMyMoneyDateInput::keyPressEvent(TQKeyEvent * k)
default:
if(today.contains(KKey(k)) || k->key() == Key_T) {
- slotDateChosen(TQDate::tqcurrentDate());
+ slotDateChosen(TQDate::currentDate());
}
break;
}
}
/**
* This function receives all events that are sent to tqfocusWidget().
* Some KeyPress events are intercepted and passed to keyPressEvent.
* Otherwise they would be consumed by TQDateEdit.
*/
@@ -337,7 +337,7 @@ void kMyMoneyDateInput::resetDate(void)
setDate(m_prevDate);
}
-TQWidget* kMyMoneyDateInput::tqfocusWidget(void) const
+TQWidget* kMyMoneyDateInput::focusWidget(void) const
{
TQWidget* w = dateEdit;
while(w->focusProxy())
@@ -165,13 +165,13 @@ void kMyMoneyDateInput::show(void)
void kMyMoneyDateInput::fixSize(void)
{
- // According to a hint in the documentation of KDatePicker::tqsizeHint()
+ // According to a hint in the documentation of KDatePicker::sizeHint()
// 28 pixels should be added in each direction to obtain a better
// display of the month button. I decided, (22,14) is good
@@ -255,14 +255,14 @@ void kMyMoneyDateInput::keyPressEvent(TQKeyEvent * k)
}
/**
- * This function receives all events that are sent to tqfocusWidget().
+ * This function receives all events that are sent to focusWidget().
* Some KeyPress events are intercepted and passed to keyPressEvent.
* Otherwise they would be consumed by TQDateEdit.
diff --git a/kmymoney2/widgets/kmymoneydateinput.h b/kmymoney2/widgets/kmymoneydateinput.h
index 2b72936..c47abb6 100644
--- a/kmymoney2/widgets/kmymoneydateinput.h
+++ b/kmymoney2/widgets/kmymoneydateinput.h
@@ -77,7 +77,7 @@ public:
void setDate(TQDate date);
void loadDate(const TQDate& date);
void resetDate(void);
- TQWidget* tqfocusWidget(void) const;
+ TQWidget* focusWidget(void) const;
virtual void setRange(const TQDate & min, const TQDate & max) { dateEdit->setRange(min, max); }
void markAsBadDate(bool bad = false, const TQColor& = TQColor());
@@ -98,7 +98,7 @@ protected:
void keyPressEvent(TQKeyEvent * k);
void resizeEvent(TQResizeEvent*);
/** To intercept events sent to tqfocusWidget() */
bool eventFilter(TQObject *o, TQEvent *e);
protected slots:
@@ -98,7 +98,7 @@ protected:
void keyPressEvent(TQKeyEvent * k);
void resizeEvent(TQResizeEvent*);
- /** To intercept events sent to tqfocusWidget() */
+ /** To intercept events sent to focusWidget() */
bool eventFilter(TQObject *o, TQEvent *e);
protected slots:
diff --git a/kmymoney2/widgets/kmymoneydatetbl.h b/kmymoney2/widgets/kmymoneydatetbl.h
index 96e57ee..7de402d 100644
--- a/kmymoney2/widgets/kmymoneydatetbl.h
+++ b/kmymoney2/widgets/kmymoneydatetbl.h
@@ -75,16 +75,16 @@ public:
* The constructor.
*/
kMyMoneyDateTbl(TQWidget *parent=0,
- TQDate date=TQDate::tqcurrentDate(),
+ TQDate date=TQDate::currentDate(),
const char* name=0, WFlags f=0);
/**
* Returns a recommended size for the widget.
* To save some time, the size of the largest used cell content is
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
* tqsizeHint() simply returns a multiple of maxCell.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* Set the font size of the date table.
*/
@@ -75,16 +75,16 @@ public:
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
- * tqsizeHint() simply returns a multiple of maxCell.
+ * sizeHint() simply returns a multiple of maxCell.
*/
diff --git a/kmymoney2/widgets/transactionform.cpp b/kmymoney2/widgets/transactionform.cpp
index b1d55cd..281bcc5 100644
--- a/kmymoney2/widgets/transactionform.cpp
+++ b/kmymoney2/widgets/transactionform.cpp
@@ -237,8 +237,8 @@ void TransactionForm::slotSetTransaction(KMyMoneyRegister::Transaction* transact
kMyMoneyDateInput dateInput(0, "editDate");
KMyMoneyCategory category(0, "category", true);
- // extract the maximal tqsizeHint height
- int height = TQMAX(dateInput.tqsizeHint().height(), category.tqsizeHint().height());
+ // extract the maximal sizeHint height
+ int height = TQMAX(dateInput.sizeHint().height(), category.sizeHint().height());
for(int row = 0; row < numRows(); ++row) {
if(!transaction || transaction->showRowInForm(row)) {
@@ -273,7 +273,7 @@ TabBar* TransactionForm::tabBar(TQWidget* parent)
// create the tab bar
m_tabBar = new TabBar( parent );
m_tabBar->setSignalEmission(TabBar::SignalAlways);
- m_tabBar->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, m_tabBar->sizePolicy().hasHeightForWidth() ) );
+ m_tabBar->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, m_tabBar->sizePolicy().hasHeightForWidth() ) );
connect(m_tabBar, TQT_SIGNAL(tabSelected(int)), this, TQT_SLOT(slotActionSelected(int)));
}
return m_tabBar;
@@ -387,9 +387,9 @@ TQSize TransactionForm::tableSize(void) const
rowPos(numRows()-1) + rowHeight(numRows()-1) + 10);
}
-TQSize TransactionForm::tqsizeHint(void) const
+TQSize TransactionForm::sizeHint(void) const
{
// I've taken this from qtable.cpp, TQTable::tqsizeHint()
int vmargin = TQApplication::reverseLayout() ? rightMargin() : leftMargin();
return TQSize(tableSize().width() + vmargin + 5, tableSize().height() + topMargin() + 10);
}
@@ -403,7 +403,7 @@ void TransactionForm::adjustColumn(Column col)
if(col == ValueColumn2) {
kMyMoneyDateInput dateInput;
kMyMoneyEdit valInput;
- w = TQMAX(dateInput.tqsizeHint().width(), valInput.tqsizeHint().width());
+ w = TQMAX(dateInput.sizeHint().width(), valInput.sizeHint().width());
}
if(m_transaction) {
@@ -416,7 +416,7 @@ void TransactionForm::adjustColumn(Column col)
m_transaction->formCellText(txt, align, i, static_cast<int>(col), 0);
TQWidget* cw = cellWidget(i, col);
if(cw) {
- w = TQMAX(w, cw->tqsizeHint().width()+10);
+ w = TQMAX(w, cw->sizeHint().width()+10);
}
w = TQMAX(w, fontMetrics.width(txt)+10);
}
@@ -387,9 +387,9 @@ TQSize TransactionForm::tableSize(void) const
{
- // I've taken this from qtable.cpp, TQTable::tqsizeHint()
+ // I've taken this from qtable.cpp, TQTable::sizeHint()
int vmargin = TQApplication::reverseLayout() ? rightMargin() : leftMargin();
return TQSize(tableSize().width() + vmargin + 5, tableSize().height() + topMargin() + 10);